@@ -6,5 +6,5 @@ from .abstract import Abstract
 class Analysis(Abstract):
   '''Webapp Analysis class'''
   def __init__(self, cfg):
-    super().__init__(cfg)
+    super(Analysis, self).__init__(cfg)
     self.endpoint += 'analyses/'
